=====
Getting Started
=====

To use bs_ds in a project::

    # For best experience:
    from bs_ds import *

    # Recommended handle
    import bs_ds as bs

To use bs_ds in an online learn.co lesson::

    !pip install bs_ds
    from bs_ds import *

For brief into to use bs_ds for EDA:
    https://drive.google.com/open?id=1B54tCSnKzsfIN3fHaJrp3oHIwQKJqmSi
